@@ -3,6 +3,7 @@ import unittest
 import subprocess
 import time
 import logging
+import warnings
 from math import ceil
 from psutil import cpu_count, virtual_memory
 
@@ -142,7 +143,11 @@ class TestSetup(TestSwifter):
                 ).swifter.resample("3T"),
             ],
             [0.5, 0.99, 52428800],
-            [ceil(virtual_memory().available * 0.5), ceil(virtual_memory().available * 0.99), 52428800,],
+            [
+                ceil(virtual_memory().available * 0.5),
+                ceil(virtual_memory().available * 0.99),
+                52428800,
+            ],
         ):
             before = swifter_df._ray_memory
             swifter_df.set_ray_compute(num_cpus=1, memory=set_ray_memory)
@@ -470,6 +475,31 @@ class TestPandasDataFrame(TestSwifter):
         if self.ncores > 1:  # speed test
             self.assertLess(swifter_time, pd_time)
 
+    def test_nonvectorized_text_modin_apply_on_large_dataframe_returns_series(self):
+        LOG.info("test_nonvectorized_text_modin_apply_on_large_dataframe_returns_series")
+        df = pd.DataFrame({"str_date": ["2000/01/01 00:00:00"] * 1_000_000})
+
+        tqdm.pandas(desc="Pandas Nonvec text apply ~ DF -> Srs")
+        start_pd = time.time()
+        pd_val = df.progress_apply(lambda row: row["str_date"].split()[0], axis=1)
+        end_pd = time.time()
+        pd_time = end_pd - start_pd
+
+        start_swifter = time.time()
+        swifter_val = (
+            df.swifter.allow_dask_on_strings(False)
+            .set_npartitions(4)
+            .set_ray_compute(num_cpus=2 if self.ncores >= 2 else 1, memory=0.25)
+            .progress_bar(desc="Nonvec Modin text apply ~ DF -> Srs")
+            .apply(lambda row: row["str_date"].split()[0], axis=1)
+        )
+        end_swifter = time.time()
+        swifter_time = end_swifter - start_swifter
+
+        self.assertEqual(pd_val, swifter_val)  # equality test
+        if self.ncores > 1:  # speed test
+            self.assertLess(swifter_time, pd_time)
+
     def test_vectorized_math_applymap_on_large_dataframe(self):
         LOG.info("test_vectorized_math_applymap_on_large_dataframe")
         df = pd.DataFrame({"x": np.random.normal(size=1_000_000), "y": np.random.uniform(size=1_000_000)})
@@ -650,6 +680,40 @@ class TestPandasTransformation(TestSwifter):
 
 
 class TestModinSeries(TestSwifter):
+    def test_modin_series_warns_on_missing_attributes(self):
+        LOG.info("test_modin_series_warns_on_missing_attributes")
+        md = self.modinSetUp()
+        series = md.Series()
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            series.swifter.set_dask_threshold(1)
+            self.assertEqual(len(w), 1)
+
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            series.swifter.set_dask_scheduler("threads")
+            self.assertEqual(len(w), 1)
+
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            series.swifter.allow_dask_on_strings(True)
+            self.assertEqual(len(w), 1)
+
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            series.swifter.progress_bar(False)
+            self.assertEqual(len(w), 1)
+
+    def test_modin_series_errors_on_missing_transformations(self):
+        LOG.info("test_modin_series_errors_on_missing_transformations")
+        md = self.modinSetUp()
+        series = md.Series()
+        with self.assertRaises(NotImplementedError):
+            series.swifter.rolling(1)
+
+        with self.assertRaises(NotImplementedError):
+            series.swifter.resample(1)
+
     def test_apply_on_empty_modin_series(self):
         LOG.info("test_apply_on_empty_series")
         md = self.modinSetUp()
@@ -690,6 +754,40 @@ class TestModinSeries(TestSwifter):
 
 
 class TestModinDataFrame(TestSwifter):
+    def test_modin_dataframe_warns_on_missing_attributes(self):
+        LOG.info("test_modin_dataframe_warns_on_missing_attributes")
+        md = self.modinSetUp()
+        df = md.DataFrame()
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            df.swifter.set_dask_threshold(1)
+            self.assertEqual(len(w), 1)
+
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            df.swifter.set_dask_scheduler("threads")
+            self.assertEqual(len(w), 1)
+
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            df.swifter.allow_dask_on_strings(True)
+            self.assertEqual(len(w), 1)
+
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            df.swifter.progress_bar(False)
+            self.assertEqual(len(w), 1)
+
+    def test_modin_dataframe_errors_on_missing_transformations(self):
+        LOG.info("test_modin_dataframe_errors_on_missing_transformations")
+        md = self.modinSetUp()
+        df = md.DataFrame()
+        with self.assertRaises(NotImplementedError):
+            df.swifter.rolling(1)
+
+        with self.assertRaises(NotImplementedError):
+            df.swifter.resample(1)
+
     def test_apply_on_empty_modin_dataframe(self):
         LOG.info("test_apply_on_empty_series")
         md = self.modinSetUp()
